@@ -1,6 +1,5 @@
 from flask_limiter import Limiter
 from flask import Flask
-from typing import Any, Optional
 from limits.errors import ConfigurationError
 
 
@@ -10,31 +9,21 @@ class InMemoryLimiter(Limiter):
     configuration and automatic checks
     """
 
-    logger: Any = None
-
-    def __init__(self, *args: Any, **kwargs: Any,) -> None:
-        """
-        Patch in any Flask log handlers before firing up to parent for limiter initialization
-        :param app: :class:`flask.Flask` instance to initialize the extension with.
-        :return: None
-        :raise ConfigurationError: if storage is incorrectly configured (via self.init_app -> invoked through superclass)
-        """
-        super().__init__(*args, **kwargs)
-
     def init_app(self, app: Flask) -> None:
         """
         patch self._check_storage into Flask-limiter, and ensure the storage backend is connected properly
-        app config values.
-        :param app: :class:`flask.Flask` instance to initialize the extension with.
+        Attach limiter to Flask log handlers
+        Called by ``self.__init__`` (if app supplied), else called directly - storage checks and
+        log configuration below are run in all instances.
+        :param app: ``Flask`` instance to initialize the extension with.
         :return: None
         :raise ConfigurationError: if storage is incorrectly configured
         """
         super().init_app(app=app)
         self._check_storage()
 
-        # Attach any existing Flask log handlers
         if app:
-            self.logger = app.logger
+            # Attach any existing Flask log handlers
             for handler in app.logger.handlers:
                 self.logger.debug(f"Adding log handler to limiter: {str(handler)}")
                 self.logger.addHandler(handler)
